﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;

namespace WebScreenSaver
{
    /// <summary>
    /// Interaction logic for Screen.xaml
    /// </summary>
    public partial class Screen : Window
    {

        int _monitorNumber = 0;
        Uri _displayPath = null;
        double _left, _top, _width, _height;

        /// <summary>
        /// Default constructor
        /// </summary>
        public Screen()
        {
            InitializeComponent();
            this.Hide();

        }

        /// <summary>
        /// Constructor for extra monitors
        /// </summary>
        /// <param name="monitorNumber"></param>
        public Screen(String displayPath, int monitorNumber, double left, double top, double width, double height)
        {

            // setup window instance
            InitializeComponent();

            // setup private vars
            _monitorNumber = monitorNumber;
            _left = left;
            _top = top;
            _width = width;
            _height = height;

            if (displayPath.Length > 2)
            {
                try
                {
                    _displayPath = new Uri(displayPath);
                }
                catch (Exception e) {
                    _displayPath = null;
                }
            }
            else {
                _displayPath = null;
            }

            //setup reference to this window (there must be away to do this diretly in xaml?)
            ObjectDataProvider screenProvider = (ObjectDataProvider)this.FindResource("thisScreen");
            screenProvider.ObjectInstance = this;

            SetupWindow();

        }

        private void SetupWindow() { 
        
                 //setup window
            this.Name = String.Format("WebScreenSaver{0}",_monitorNumber);
            this.Title = String.Format("WebScreenSaver{0}", _monitorNumber);
            
            if (_displayPath != null){
            this.frame1.Source = _displayPath;
            }

            // setup window for display
            this.Left = _left;
            this.Top = _top;
            this.Width = _width;
            this.Height = _height;
            this.WindowStyle = WindowStyle.None;
        }

        public string MonitorNumber
        {
            get {
                return (_monitorNumber+1).ToString();
            }
            private set { }
        }

        public string MonitorDescription
        {
            get
            {
                if (_displayPath != null)
                {
                    return String.Format("Set to load '{0}'.\n(Double click this screen in interactive mode [Esc] to configure)", _displayPath.ToString());
                }
                else {
                    return "A path is not set for this monitor or the path is invalid.\n(Double click this screen in interactive mode [Esc] to configure)";
                }
            }
            private set {}
        }

        private void Window_Loaded(object sender, RoutedEventArgs e) {
            // maximise window - this must be on window load event to work properly
            WindowState = WindowState.Maximized;

        }

        private void Window_DoubleClick(object sender, System.Windows.Input.MouseButtonEventArgs e)
        {
            Settings settings = new Settings();
            settings.Topmost = true;
            settings.Show();
        }

        

        

    }
}
