﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;

namespace WebScreenSaver
{
    public class ScreenSetting : IComparable, INotifyPropertyChanged
    {

        private int _monitorNumber;
        private string _path;

        public ScreenSetting(int monitorNumber, string path) {
            _monitorNumber = monitorNumber;
            _path = path.Trim();
            
        }

        public string Name {
            get {
                return String.Format("Screen {0} Path",_monitorNumber+1);
            }
            private set { }
        }

        public int MonitorNumber {
            get {
                return _monitorNumber;
            }
            set {
                _monitorNumber = value;
                Notify("MonitorNumber");
                Notify("Name");
            }
        }

        public string Path {
            get {
                return _path;
            }
            set {
                _path = value.Trim();
                Notify("Path");
                Notify("IsValidPath");
            }
        }

        public System.Windows.Visibility IsValidPath {
            get {
                if (_path.Length > 2)
                {
                    try
                    {
                        new Uri(_path);
                        return System.Windows.Visibility.Hidden;
                    }
                    catch (Exception e)
                    {
                        return System.Windows.Visibility.Visible;
                    }
                }
                else
                {
                    return System.Windows.Visibility.Visible;
                }
            }

            private set { } 
        }



        #region IComparable Members

        public int CompareTo(object obj)
        {
            if (obj is ScreenSetting)
            {
                return _monitorNumber - ((ScreenSetting)obj).MonitorNumber;
            }
            else
            {
                throw new NotImplementedException(String.Format("Comparison of '{0} on ScreenSetting not implemented'", obj.GetType().ToString()));
            }
       }

        #endregion


        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        protected void Notify(string propName)
        {
            if (this.PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propName));
            }
        }

        #endregion
    }
}
