﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Collections.ObjectModel;

namespace WebScreenSaver
{
    /// <summary>
    /// Interaction logic for Settings.xaml
    /// </summary>
    public partial class Settings : Window
    {

        ScreenSettings _screenSettings = new ScreenSettings(Properties.Settings.Default.DisplayPaths);
        bool _saveScreen = Properties.Settings.Default.SaveScreen;
        bool _interactiveModeAllowed = Properties.Settings.Default.InteractiveModeAllowed;

        public Settings()
        {
            InitializeComponent();

            //setup reference to this window (there must be away to do this diretly in xaml?)
            ObjectDataProvider screenProvider = (ObjectDataProvider)this.FindResource("thisScreen");
            screenProvider.ObjectInstance = this;
        }

        public bool InteractiveModeAllowed {
            get {
                return _interactiveModeAllowed;
            }

            set {
                _interactiveModeAllowed = value;
            } 
        }

        public bool SaveScreen {
            get {
                return _saveScreen;
            }

            set {
                _saveScreen = value;
            }
        }

        public ScreenSettings ScreenSettings {
            get {

                return _screenSettings;

            }
            private set {
            }
        }

        private void bCancel_Click(object sender, RoutedEventArgs e)
        {
            //todo check we don't need to reload the settings when user cancels (eg if we bind to settings directly has the user modified them in memory)
            this.Close();
        }

        private void bSave_Click(object sender, RoutedEventArgs e)
        {
            // iterate through screen paths

            StringCollection paths = new StringCollection();

            foreach (ScreenSetting i in _screenSettings)
            {
                paths.Add(i.Path);
            }

            // save new paths
            Properties.Settings.Default.DisplayPaths = paths;

            //save boolean settings
            Properties.Settings.Default.SaveScreen = _saveScreen;
            Properties.Settings.Default.InteractiveModeAllowed = _interactiveModeAllowed;

            //save settings
            WebScreenSaver.Properties.Settings.Default.Save();
            
            this.Close();
        }

        private void bAdd_Click(object sender, RoutedEventArgs e)
        {
            _screenSettings.Add(new ScreenSetting(_screenSettings.Count, ""));
            lbScreenPaths.Focus();
            lbScreenPaths.UnselectAll();
            lbScreenPaths.SelectedIndex = _screenSettings.Count - 1;
        }

        private void bRemove_Click(Object sender, RoutedEventArgs e)
        {
            if (lbScreenPaths.SelectedIndex >= 0 && lbScreenPaths.SelectedIndex < _screenSettings.Count) {
                // get position
                int theIndex = lbScreenPaths.SelectedIndex;
                lbScreenPaths.Focus();
                lbScreenPaths.UnselectAll();

                // remove node/setting
                _screenSettings.RemoveAt(theIndex);

                //iterate screenSettings after removed one and fix monitor number
                for (int i = theIndex; i < _screenSettings.Count; i++) {
                    _screenSettings[i].MonitorNumber = i;
                }
                lbScreenPaths.SelectedIndex = _screenSettings.Count - 1;
            }
        }

        private void bUp_Click(object sender, RoutedEventArgs e)
        {
            if (lbScreenPaths.SelectedIndex > 0 && lbScreenPaths.SelectedIndex < _screenSettings.Count)
            {
                // get position
                int theIndex = lbScreenPaths.SelectedIndex;
                lbScreenPaths.Focus();
                lbScreenPaths.UnselectAll();

                // save selected index item
                ScreenSetting temp = _screenSettings[theIndex];

                // swap above item to selected position
                _screenSettings[theIndex] = _screenSettings[theIndex - 1];
                _screenSettings[theIndex].MonitorNumber = theIndex;

                // set selected item to above position
                _screenSettings[theIndex - 1] = temp;
                _screenSettings[theIndex - 1].MonitorNumber = theIndex - 1;


                lbScreenPaths.SelectedIndex = theIndex - 1;
            }
            else {
                lbScreenPaths.Focus();
            }
        }

        private void bDown_Click(object sender, RoutedEventArgs e)
        {
            if (lbScreenPaths.SelectedIndex >= 0 && lbScreenPaths.SelectedIndex < _screenSettings.Count-1)
            {
                // get position
                int theIndex = lbScreenPaths.SelectedIndex;
                lbScreenPaths.Focus();
                lbScreenPaths.UnselectAll();

                // save selected index item
                ScreenSetting temp = _screenSettings[theIndex];

                // swap above item to selected position
                _screenSettings[theIndex] = _screenSettings[theIndex + 1];
                _screenSettings[theIndex].MonitorNumber = theIndex;

                // set selected item to above position
                _screenSettings[theIndex + 1] = temp;
                _screenSettings[theIndex + 1].MonitorNumber = theIndex +1;

                lbScreenPaths.SelectedIndex = theIndex + 1;
            }
            else
            {
                lbScreenPaths.Focus();
            }
        }

        void HandleRequestNavigate(object sender, RoutedEventArgs e) 
        { 
            string navigateUri = hl.NavigateUri.ToString(); 
            System.Diagnostics.Process.Start(new System.Diagnostics.ProcessStartInfo(navigateUri)); e.Handled = true; 
        }

    }
}
